#-----------------------------------------------------------------------
# File    : cluster.mak
# Contents: commands to build clustering programs
# Author  : Christian Borgelt
# History : 2003.02.02 file created
#           2003.05.17 cluster evaluation programs added
#           2003.08.11 adapted to new module attmap
#           2003.08.12 adapted to new module nstats
#           2006.07.20 adapted to Visual Studio 8
#           2007.03.16 special matrix versions removed
#-----------------------------------------------------------------------
THISDIR  = ..\..\cluster\src
MATHDIR  = ..\..\math\src
UTILDIR  = ..\..\util\src
MATDIR   = ..\..\matrix\src
TABLEDIR = ..\..\table\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(MATHDIR) /I $(UTILDIR) /I $(MATDIR) /I $(TABLEDIR)

LD       = link.exe
LDFLAGS  = /nologo /subsystem:console /incremental:no
LIBS     = 

HDRS_1   = $(UTILDIR)\fntypes.h    $(UTILDIR)\nstats.h     \
           $(MATHDIR)\radfn.h      $(MATDIR)\matrix.h
HDRS_2   = $(HDRS_1)               $(UTILDIR)\arrays.h     \
           $(UTILDIR)\scanner.h
HDRS_3   = $(HDRS_2)               $(TABLEDIR)\attset.h    \
           $(TABLEDIR)\attmap.h    $(TABLEDIR)\table.h
HDRS     = $(HDRS_3)               $(UTILDIR)\error.h      \
           $(UTILDIR)\tabread.h    $(UTILDIR)\tabwrite.h   \
           cluster.h
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\escape.obj   \
           $(UTILDIR)\tabread.obj  $(UTILDIR)\tabwrite.obj \
           $(UTILDIR)\scanner.obj  $(UTILDIR)\nst_pars.obj \
           $(MATHDIR)\gamma.obj    $(MATHDIR)\radfn.obj    \
           $(MATDIR)\mat_rdwr.obj  $(MATDIR)\matrix2.obj   \
           $(MATDIR)\matrix3.obj   $(TABLEDIR)\attset1.obj \
           $(TABLEDIR)\attset2.obj $(TABLEDIR)\attset3.obj \
           $(TABLEDIR)\attmap.obj  cluster1.obj
CLI_O    = $(OBJS)                 $(UTILDIR)\random.obj  \
           $(UTILDIR)\params.obj   $(TABLEDIR)\table1.obj \
		   $(TABLEDIR)\tab2rm.obj  \
		   cluster2.obj cluster3.obj cluster4.obj cli.obj
CLX_O    = $(OBJS)                 $(TABLEDIR)\table1.obj \
           $(TABLEDIR)\tab2ro.obj  clx.obj
CLE_O    = $(OBJS) cluster3.obj    cle.obj
CLC_O    = $(OBJS) $(MATDIR)\matrix4.obj clc.obj
PRGS     = cli.exe clx.exe cle.exe clc.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:          $(PRGS)

cli.exe:      $(CLI_O) cluster.mak
	$(LD) $(LDFLAGS) $(CLI_O) $(LIBS) /out:$@

clx.exe:      $(CLX_O) cluster.mak
	$(LD) $(LDFLAGS) $(CLX_O) $(LIBS) /out:$@

cle.exe:      $(CLE_O) cluster.mak
	$(LD) $(LDFLAGS) $(CLE_O) $(LIBS) /out:$@

clc.exe:      $(CLC_O) cluster.mak
	$(LD) $(LDFLAGS) $(CLC_O) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
cli.obj:      $(HDRS) $(UTILDIR)\random.h $(UTILDIR)\params.h
cli.obj:      cli.c cluster.mak
	$(CC) $(CFLAGS) $(INCS) cli.c /Fo$@

clx.obj:      $(HDRS)
clx.obj:      clx.c cluster.mak
	$(CC) $(CFLAGS) $(INCS) clx.c /Fo$@

cle.obj:      $(HDRS)
cle.obj:      cle.c cluster.mak
	$(CC) $(CFLAGS) $(INCS) cle.c /Fo$@

clc.obj:      $(HDRS)
clc.obj:      clc.c cluster.mak
	$(CC) $(CFLAGS) $(INCS) clc.c /Fo$@

#-----------------------------------------------------------------------
# Cluster and Cluster Set Management
#-----------------------------------------------------------------------
cluster1.obj: $(UTILDIR)\fntypes.h  $(UTILDIR)\arrays.h  \
              $(UTILDIR)\nstats.h   $(UTILDIR)\scanner.h \
              $(MATHDIR)\radfn.h    $(MATDIR)\matrix.h
cluster1.obj: cluster.h cluster1.c cluster.mak
	$(CC) $(CFLAGS) $(INCS) /D CLS_PARSE cluster1.c /Fo$@

cluster2.obj: $(UTILDIR)\fntypes.h  $(UTILDIR)\nstats.h \
              $(MATHDIR)\radfn.h    $(MATDIR)\matrix.h
cluster2.obj: cluster.h cluster2.c cluster.mak
	$(CC) $(CFLAGS) $(INCS) cluster2.c /Fo$@

cluster3.obj: $(UTILDIR)\fntypes.h  $(UTILDIR)\nstats.h \
              $(MATHDIR)\radfn.h    $(MATDIR)\matrix.h
cluster3.obj: cluster.h cluster3.c cluster.mak
	$(CC) $(CFLAGS) $(INCS) cluster3.c /Fo$@

cluster4.obj: $(UTILDIR)\fntypes.h  $(UTILDIR)\nstats.h \
              $(MATHDIR)\radfn.h    $(MATDIR)\matrix.h
cluster4.obj: cluster.h cluster4.c cluster.mak
	$(CC) $(CFLAGS) $(INCS) cluster4.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(MATHDIR)\gamma.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak gamma.obj
	cd $(THISDIR)
$(MATHDIR)\radfn.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak radfn.obj
	cd $(THISDIR)
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\nst_pars.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak nst_pars.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\tabwrite.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabwrite.obj
	cd $(THISDIR)
$(UTILDIR)\scanner.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scanner.obj
	cd $(THISDIR)
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)
$(UTILDIR)\params.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak params.obj
	cd $(THISDIR)
$(MATDIR)\mat_rdwr.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak mat_rdwr.obj
	cd $(THISDIR)
$(MATDIR)\matrix1.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix1.obj
	cd $(THISDIR)
$(MATDIR)\matrix2.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix2.obj
	cd $(THISDIR)
$(MATDIR)\matrix3.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix3.obj
	cd $(THISDIR)
$(MATDIR)\matrix4.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix4.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\attmap.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attmap.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2ro.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2ro.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2rm.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2rm.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f cluster.mak localclean
	cd $(MATHDIR)
	$(MAKE) /f math.mak clean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(MATDIR)
	$(MAKE) /f matrix.mak localclean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch $(PRGS)
